
from landlab.components.plant_competition_ca.plant_competition_ca import VegCA


__all__ = ["VegCA"]
